<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>Arqiver::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="160"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
</context>
<context>
    <name>Arqiver::Backend</name>
    <message>
        <location filename="../../backends.cpp" line="840"/>
        <source>This file is a link but its target does not exist.</source>
        <translation>Ce fichier est un lien mais sa cible n’existe pas.</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1261"/>
        <location filename="../../backends.cpp" line="1293"/>
        <location filename="../../backends.cpp" line="1337"/>
        <source>Could not read archive</source>
        <translation>Impossible de lire l’archive</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1296"/>
        <location filename="../../backends.cpp" line="1342"/>
        <source>Archive Loaded</source>
        <translation>Archive chargée</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1303"/>
        <location filename="../../backends.cpp" line="1390"/>
        <source>Modification Finished</source>
        <translation>Modification terminée</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1324"/>
        <location filename="../../backends.cpp" line="1359"/>
        <source>Extraction Finished</source>
        <translation>Extraction terminée</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1327"/>
        <location filename="../../backends.cpp" line="1378"/>
        <source>Extraction Failed</source>
        <translation>L’extraction a échoué</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1475"/>
        <source>%1 is missing from your system.
Please install it for this kind of archive!</source>
        <translation>%1 est manquant dans votre système.
Veuillez l’installer pour ce genre d’archive&#xa0;!</translation>
    </message>
</context>
<context>
    <name>Arqiver::LineEdit</name>
    <message>
        <location filename="../../lineedit.h" line="33"/>
        <source>You could type inside the main view.
Clear text with the Escape key.</source>
        <translation>Vous pouvez taper dans la vue principale.
Effacez le texte avec la touche Echap.</translation>
    </message>
</context>
<context>
    <name>Arqiver::PrefDialog</name>
    <message>
        <location filename="../../pref.ui" line="14"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="50"/>
        <source>Start with this size:</source>
        <translation>Commencer par cette taille&#xa0;:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="118"/>
        <source>Use system icons where possible</source>
        <translation>Utiliser les icônes du système lorsque cela est possible</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="125"/>
        <source>Show prompt on removing items</source>
        <translation>Afficher l’invite lors de la suppression d’éléments</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="132"/>
        <source>If this is unchecked, only the top level directories will be expanded.</source>
        <translation>Si cette option n’est pas cochée, seuls les répertoires de niveau supérieur seront développés.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="135"/>
        <source>Expand all directories when opening archives</source>
        <translation>Développer tous les répertoires lors de l’ouverture des archives</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="147"/>
        <location filename="../../pref.ui" line="160"/>
        <source>Leave empty for the default.

Warning: Arqiver will not work if the
binary does not belong to libarchive.</source>
        <translation>Laissez vide pour la valeur par défaut.

Attention&#xa0;: Arqiver ne fonctionnera pas si le
binaire n’appartient pas à libarchive.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="153"/>
        <source>libarchive binary:</source>
        <translation>binaire libarchive&#xa0;:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="38"/>
        <source>Remember window &amp;size on closing</source>
        <translation>Se souvenir de la &amp;taille de la fenêtre à la fermeture</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="93"/>
        <source>Size of view icons:</source>
        <translation>Taille des icônes de vue&#xa0;:</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="62"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="184"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Le redémarrage de l’application est nécessaire pour que les modifications prennent effet.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="241"/>
        <source>Select libarchive binary</source>
        <translation>Sélectionner le binaire libarchive</translation>
    </message>
</context>
<context>
    <name>Arqiver::mainWin</name>
    <message>
        <location filename="../../mainWin.ui" line="53"/>
        <source>Archive:</source>
        <translation>Archive&#xa0;:</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="106"/>
        <source>Filter Files...</source>
        <translation>Filtrer les fichiers...</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="140"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edition</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="155"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="166"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="204"/>
        <source>&amp;Open Archive</source>
        <translation>&amp;Ouvrir une Archive</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="207"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="212"/>
        <source>&amp;New Archive</source>
        <translation>&amp;Nouvelle Archive</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="215"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="220"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="223"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="228"/>
        <source>Add File(s)</source>
        <translation>Ajouter des fichiers</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="233"/>
        <source>Remove File(s)</source>
        <translation>Supprimer le(s) fichier(s)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="238"/>
        <source>Extract All</source>
        <translation>Extraire tout</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="241"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="246"/>
        <source>Add Directory</source>
        <translation>Ajouter un répertoire</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="251"/>
        <source>Extract Selection</source>
        <translation>Extraire la sélection</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="256"/>
        <source>Set Password</source>
        <translation>Définir le mot de passe</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="261"/>
        <source>E&amp;xpand</source>
        <translation>Dé&amp;velopper</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="264"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Maj+Bas</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="269"/>
        <source>Collap&amp;se</source>
        <translation>Effond&amp;rer</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="272"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Maj+Haut</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="277"/>
        <source>&amp;About</source>
        <translation>&amp;A propos</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="282"/>
        <source>&amp;Copy Current Path</source>
        <translation>&amp;Copier le chemin actuel</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="287"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="292"/>
        <source>Stop &amp;Process</source>
        <translation>Arrêter &amp;Traiter</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="295"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="305"/>
        <source>Update Archive</source>
        <translation>Mettre à jour l’archive</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="147"/>
        <source>Root</source>
        <translation>Racine</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="252"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>MimeType</source>
        <translation>MimeType</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="553"/>
        <location filename="../../mainWin.cpp" line="838"/>
        <location filename="../../mainWin.cpp" line="882"/>
        <source>Opening Archive...</source>
        <translation>Ouverture de l’archive...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="767"/>
        <source>Create Archive</source>
        <translation>Créer une archive</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="464"/>
        <location filename="../../mainWin.cpp" line="793"/>
        <location filename="../../mainWin.cpp" line="992"/>
        <location filename="../../mainWin.cpp" line="1300"/>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="794"/>
        <source>The following archive already exists:</source>
        <translation>L’archive suivante existe déjà&#xa0;:</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="796"/>
        <source>Do you want to replace it?
</source>
        <translation>Voulez-vous le remplacer&#xa0;?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="830"/>
        <source>Open Archive</source>
        <translation>Ouvrir l’archive</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="897"/>
        <location filename="../../mainWin.cpp" line="904"/>
        <location filename="../../mainWin.cpp" line="941"/>
        <source>Add to Archive</source>
        <translation>Ajouter à l’archive</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="936"/>
        <location filename="../../mainWin.cpp" line="967"/>
        <location filename="../../mainWin.cpp" line="1252"/>
        <location filename="../../mainWin.cpp" line="1258"/>
        <source>Adding Items...</source>
        <translation>Ajout d’éléments...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="993"/>
        <source>Do you want to remove the selected item(s)?
</source>
        <translation>Voulez-vous supprimer le ou les éléments sélectionnés&#xa0;?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1012"/>
        <source>Removing Items...</source>
        <translation>Suppression d’éléments...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1215"/>
        <location filename="../../mainWin.cpp" line="1230"/>
        <location filename="../../mainWin.cpp" line="1315"/>
        <location filename="../../mainWin.cpp" line="1329"/>
        <source>Extracting...</source>
        <translation>Extraction...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1056"/>
        <source>Copy Archive Path</source>
        <translation>Copier le chemin de l’archive</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="465"/>
        <source>Some files have been modified.</source>
        <translation>Certains fichiers ont été modifiés.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="466"/>
        <source>Do you want to ignore the changes?
</source>
        <translation>Voulez-vous ignorer les changements ?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="627"/>
        <source>All Types</source>
        <translation>Tous types</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="637"/>
        <location filename="../../mainWin.cpp" line="661"/>
        <source>Uncompressed Archive</source>
        <translation>Archive non compressée</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="638"/>
        <location filename="../../mainWin.cpp" line="662"/>
        <source>GZip Compressed Archive</source>
        <translation>Archive compressée GZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="639"/>
        <location filename="../../mainWin.cpp" line="663"/>
        <location filename="../../mainWin.cpp" line="664"/>
        <source>BZip Compressed Archive</source>
        <translation>Archive compressée BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="640"/>
        <location filename="../../mainWin.cpp" line="665"/>
        <source>BZip2 Compressed Archive</source>
        <translation>Archive compressée BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="641"/>
        <location filename="../../mainWin.cpp" line="673"/>
        <source>LMZA Compressed Archive</source>
        <translation>Archive compressée LMZA</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="642"/>
        <location filename="../../mainWin.cpp" line="670"/>
        <source>XZ Compressed Archive</source>
        <translation>Archive compressée XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="643"/>
        <location filename="../../mainWin.cpp" line="674"/>
        <source>Zstandard Compressed Archive</source>
        <translation>Archive compressée Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="644"/>
        <location filename="../../mainWin.cpp" line="676"/>
        <source>CPIO Archive</source>
        <translation>Archive CPIO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="646"/>
        <location filename="../../mainWin.cpp" line="678"/>
        <source>AR Archive</source>
        <translation>Archive AR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="648"/>
        <location filename="../../mainWin.cpp" line="680"/>
        <source>Zip Archive</source>
        <translation>Archive Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="649"/>
        <location filename="../../mainWin.cpp" line="682"/>
        <source>Gzip Archive</source>
        <translation>Archives Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="650"/>
        <location filename="../../mainWin.cpp" line="681"/>
        <source>7-Zip Archive</source>
        <translation>Archive 7-Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="666"/>
        <location filename="../../mainWin.cpp" line="667"/>
        <source>READ-ONLY: BZip Archive</source>
        <translation>LECTURE SEULE : Archive BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="668"/>
        <source>READ-ONLY: BZip2 Archive</source>
        <translation>LECTURE SEULE&#xa0;: Archive BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="669"/>
        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
        <translation>LECTURE SEULE&#xa0;: Document PDF compressé BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="671"/>
        <source>READ-ONLY: XZ archive</source>
        <translation>LECTURE SEULE&#xa0;: Archive XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="672"/>
        <source>READ-ONLY: XZ Compressed PDF Document</source>
        <translation>LECTURE SEULE&#xa0;: Document PDF compressé XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="675"/>
        <source>READ-ONLY: Zstandard archive</source>
        <translation>LECTURE SEULE&#xa0;: Archive Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="683"/>
        <source>Gzip Compressed PDF Document</source>
        <translation>Document PDF compressé Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="684"/>
        <source>READ-ONLY: Compressed SVG Image</source>
        <translation>LECTURE SEULE&#xa0;: Image SVG compressée</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="685"/>
        <location filename="../../mainWin.cpp" line="686"/>
        <location filename="../../mainWin.cpp" line="687"/>
        <location filename="../../mainWin.cpp" line="688"/>
        <source>READ-ONLY: ISO Image</source>
        <translation>LECTURE SEULE&#xa0;: Image ISO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="689"/>
        <source>READ-ONLY: XAR Archive</source>
        <translation>LECTURE SEULE&#xa0;: Archive XAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="690"/>
        <source>READ-ONLY: Java Archive</source>
        <translation>LECTURE SEULE&#xa0;: Archive Java</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="691"/>
        <source>READ-ONLY: Debian Package</source>
        <translation>LECTURE SEULE&#xa0;: Paquet Debian</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="692"/>
        <location filename="../../mainWin.cpp" line="693"/>
        <source>READ-ONLY: RedHat Package</source>
        <translation>LECTURE SEULE&#xa0;: Paquet RedHat</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="694"/>
        <location filename="../../mainWin.cpp" line="695"/>
        <location filename="../../mainWin.cpp" line="696"/>
        <source>READ-ONLY: MS Windows Executable</source>
        <translation>LECTURE SEULE&#xa0;: Exécutable MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="697"/>
        <source>READ-ONLY: MS Windows Installer Package</source>
        <translation>LECTURE SEULE&#xa0;: Package d’installation MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="698"/>
        <source>READ-ONLY: MS Windows Cabinet Archive</source>
        <translation>LECTURE SEULE&#xa0;: Archive MS Windows Cabinet</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="700"/>
        <source>READ-ONLY: Android Package</source>
        <translation>LECTURE SEULE&#xa0;: Package Android</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="701"/>
        <source>READ-ONLY: RAR Archive</source>
        <translation>LECTURE SEULE&#xa0;: Archive RAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="702"/>
        <source>READ-ONLY: AppImage application bundle</source>
        <translation>LECTURE SEULE&#xa0;: Ensemble d’applications AppImage</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="703"/>
        <source>READ-ONLY: VirtualBox Extension Pack</source>
        <translation>LECTURE-SEULE : Pack d’extension VirtualBox</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="712"/>
        <source>All Known Types</source>
        <translation>Tous types connus</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="717"/>
        <source>Show All Files</source>
        <translation>Afficher tous les fichiers</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1066"/>
        <source>Open Containing Folder</source>
        <translation>Ouvrir le dossier contenant</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="300"/>
        <source>View Current Item</source>
        <translation>Afficher l’élément actuel</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1111"/>
        <location filename="../../mainWin.cpp" line="1119"/>
        <source>Enter Password</source>
        <translation>Entrer le mot de passe</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1127"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1132"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1136"/>
        <source>Encrypt the file list</source>
        <translation>Crypter la liste des fichiers</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1137"/>
        <source>This will take effect after files/folders are added.</source>
        <translation>Cela prendra effet une fois que les fichiers/dossiers seront ajoutés.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1208"/>
        <location filename="../../mainWin.cpp" line="1284"/>
        <source>Extract Into Directory</source>
        <translation>Extraire dans le répertoire</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1301"/>
        <source>Some files will be overwritten.
Do you want to continue?
</source>
        <translation>Certains fichiers seront écrasés.
Voulez-vous continuer&#xa0;?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1427"/>
        <source>Link To: %1</source>
        <translation>Lien vers&#xa0;: %1</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1694"/>
        <source>Could not read archive</source>
        <translation>Impossible de lire l&apos;archive</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1765"/>
        <source>A simple Qt archive manager</source>
        <translation>Un simple gestionnaire d’archives Qt</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1766"/>
        <source>based on libarchive, gzip and 7z</source>
        <translation>basé sur libarchive, gzip et 7z</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1767"/>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1768"/>
        <source>aka.</source>
        <translation>alias.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <location filename="../../mainWin.cpp" line="1770"/>
        <source>About Arqiver</source>
        <translation>À propos d’Arqiver</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <source>Translators</source>
        <translation>Traducteurs</translation>
    </message>
</context>
</TS>
